General methods for aligned access to a byte buffer
Enums
- Buffer
Error - Error for handling a buffer
Traits
- Buffer
Ext - Additional methods on
&[u8]
Functions
- cmp_
table_ header_ name - Compares the name given by
byteswith the one referenced intable_header - get_at
- Get a reference to a type at the given address of this buffer
- get_
slice_ at - Get a reference to a slice at the given address of this buffer
- header
- Get the header of the file.
- header_
ref - Get the database header
- table_
data - Get the table data header
- table_
data_ ref - Get the table data reference
- table_
definition - Get the table definition header
- table_
definition_ ref - Get the table definition reference
- table_
headers - Get the table slice
Type Aliases
- Res
- Result with a
BufferError